@@ -8,11 +8,12 @@ from typing import TYPE_CHECKING, Any, Callable, TypeVar
 
 from typing_extensions import Protocol, runtime_checkable
 
-from . import _time
-from ._callback import invoke
-from ._easing import DEFAULT_EASING, EASING
-from ._types import AnimationLevel, CallbackType
-from .timer import Timer
+from textual import _time
+from textual._callback import invoke
+from textual._compat import cached_property
+from textual._easing import DEFAULT_EASING, EASING
+from textual._types import AnimationLevel, CallbackType
+from textual.timer import Timer
 
 if TYPE_CHECKING:
     from textual.app import App
@@ -21,7 +22,7 @@ if TYPE_CHECKING:
     """Animation keys are the id of the object and the attribute being animated."""
 
 EasingFunction = Callable[[float], float]
-"""Signature for a function that parametrises animation speed.
+"""Signature for a function that parametrizes animation speed.
 
 An easing function must map the interval [0, 1] into the interval [0, 1].
 """
@@ -242,11 +243,16 @@ class Animator:
             callback=self,
             pause=True,
         )
+
+    @cached_property
+    def _idle_event(self) -> asyncio.Event:
         """The timer that runs the animator."""
-        self._idle_event = asyncio.Event()
+        return asyncio.Event()
+
+    @cached_property
+    def _complete_event(self) -> asyncio.Event:
         """Flag if no animations are currently taking place."""
-        self._complete_event = asyncio.Event()
-        """Flag if no animations are currently taking place and none are scheduled."""
+        return asyncio.Event()
 
     async def start(self) -> None:
         """Start the animator task."""
@@ -316,6 +322,7 @@ class Animator:
             on_complete: Callback to run after the animation completes.
             level: Minimum level required for the animation to take place (inclusive).
         """
+        self._record_animation(attribute)
         animate_callback = partial(
             self._animate,
             obj,
@@ -336,6 +343,13 @@ class Animator:
         else:
             animate_callback()
 
+    def _record_animation(self, attribute: str) -> None:
+        """Called when an attribute is to be animated.
+
+        Args:
+            attribute: Attribute being animated.
+        """
+
     def _animate(
         self,
         obj: object,
@@ -438,6 +452,7 @@ class Animator:
                 ),
                 level=level,
             )
+
         assert animation is not None, "animation expected to be non-None"
 
         current_animation = self._animations.get(animation_key)
@@ -521,7 +536,7 @@ class Animator:
         Note:
             If there is no animation scheduled or running, this is a no-op.
         """
-        from .css.scalar_animation import ScalarAnimation
+        from textual.css.scalar_animation import ScalarAnimation
 
         animation_key = (id(obj), attribute)
         try:
