@@ -87,6 +87,11 @@ BORDER_CHARS: dict[
         ("█", " ", "█"),
         ("█", "▄", "█"),
     ),
+    "block": (
+        ("▄", "▄", "▄"),
+        ("█", " ", "█"),
+        ("▀", "▀", "▀"),
+    ),
     "hkey": (
         ("▔", "▔", "▔"),
         (" ", " ", " "),
@@ -190,6 +195,11 @@ BORDER_LOCATIONS: dict[
         (0, 0, 0),
         (0, 0, 0),
     ),
+    "block": (
+        (1, 1, 1),
+        (0, 0, 0),
+        (1, 1, 1),
+    ),
     "hkey": (
         (0, 0, 0),
         (0, 0, 0),
